Index: src/assembler.h |
diff --git a/src/assembler.h b/src/assembler.h |
index 9e6311dafd049e69c0e79ac867ecbf438241ebb5..b6351fae44d20f71c02b20804d4b760a28421326 100644 |
--- a/src/assembler.h |
+++ b/src/assembler.h |
@@ -578,9 +578,14 @@ class RelocInfo { |
// place, ready to be patched with the target. |
INLINE(int target_address_size()); |
+ // Read the reference in the instruction this relocation |
+ // applies to; can only be called if rmode_ is EXTERNAL_REFERENCE. |
+ INLINE(Address target_external_reference()); |
+ |
// Read/modify the reference in the instruction this relocation |
- // applies to; can only be called if rmode_ is external_reference |
- INLINE(Address target_reference()); |
+ // applies to; can only be called if rmode_ is INTERNAL_REFERENCE. |
+ INLINE(Address target_internal_reference()); |
+ INLINE(void set_target_internal_reference(Address target)); |
// Read/modify the address of a call instruction. This is used to relocate |
// the break points where straight-line code is patched with a call |